<?php
	session_start();
	if (!isset($_SESSION['view_id']))
		header("Location: index.php");

	$user_name = $_GET['user_name'];

	include "../connect/db_connect.php";
	
	// Go ahead and delete page record from table.
	$query = "DELETE FROM users WHERE UserID = '$user_name'";
	$cnt = $zen_dbh->exec($query);
	
	header("Location: users.php");
	
?>
